==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/gl.php <==
<?php

return [
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Os Emiratos Árabes Unidos',
        'AF' => 'Afganistán',
        'AG' => 'Antigua e Barbuda',
        'AI' => 'Anguila',
        'AL' => 'Albania',
        'AM' => 'Armenia',
        'AO' => 'Angola',
        'AQ' => 'A Antártida',
        'AR' => 'A Arxentina',
        'AS' => 'Samoa Americana',
        'AT' => 'Austria',
        'AU' => 'Australia',
        'AW' => 'Aruba',
        'AX' => 'Illas Åland',
        'AZ' => 'Acerbaixán',
        'BA' => 'Bosnia e Hercegovina',
        'BB' => 'Barbados',
        'BD' => 'Bangladesh',
        'BE' => 'Bélxica',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgaria',
        'BH' => 'Bahrain',
        'BI' => 'Burundi',
        'BJ' => 'Benín',
        'BL' => 'Saint Barthélemy',
        'BM' => 'Illas Bermudas',
        'BN' => 'Brunei',
        'BO' => 'Bolivia',
        'BQ' => 'Caribe Neerlandés',
        'BR' => 'O Brasil',
        'BS' => 'Bahamas',
        'BT' => 'Bután',
        'BV' => 'Illa Bouvet',
        'BW' => 'Botswana',
        'BY' => 'Belarús',
        'BZ' => 'Belize',
        'CA' => 'O Canadá',
        'CC' => 'Illas Cocos (Keeling)',
        'CD' => 'República Democrática do Congo',
        'CF' => 'República Centroafricana',
        'CG' => 'República do Congo',
        'CH' => 'Suíza',
        'CI' => 'Côte d’Ivoire',
        'CK' => 'Illas Cook',
        'CL' => 'Chile',
        'CM' => 'Camerún',
        'CN' => 'A China',
        'CO' => 'Colombia',
        'CR' => 'Costa Rica',
        'CU' => 'Cuba',
        'CV' => 'Cabo Verde',
        'CW' => 'Curaçao',
        'CX' => 'Illa Christmas',
        'CY' => 'Chipre',
        'CZ' => 'Chequia',
        'DE' => 'Alemaña',
        'DJ' => 'Djibuti',
        'DK' => 'Dinamarca',
        'DM' => 'Dominica',
        'DO' => 'República Dominicana',
        'DZ' => 'Alxeria',
        'EC' => 'Ecuador',
        'EE' => 'Estonia',
        'EG' => 'Exipto',
        'EH' => 'O Sáhara Occidental',
        'ER' => 'Eritrea',
        'ES' => 'España',
        'ET' => 'Etiopía',
        'FI' => 'Finlandia',
        'FJ' => 'Fixi',
        'FK' => 'Illas Malvinas',
        'FM' => 'Micronesia',
        'FO' => 'Illas Feroe',
        'FR' => 'Francia',
        'GA' => 'Gabón',
        'GB' => 'O Reino Unido',
        'GD' => 'Granada',
        'GE' => 'Xeorxia',
        'GF' => 'Güiana Francesa',
        'GG' => 'Guernsey',
        'GH' => 'Ghana',
        'GI' => 'Xibraltar',
        'GL' => 'Groenlandia',
        'GM' => 'Gambia',
        'GN' => 'Guinea',
        'GP' => 'Guadalupe',
        'GQ' => 'Guinea Ecuatorial',
        'GR' => 'Grecia',
        'GS' => 'Illas Xeorxia do Sur e Sandwich do Sur',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'A Guinea Bissau',
        'GY' => 'Güiana',
        'HK' => 'Hong Kong RAE da China',
        'HM' => 'Illa Heard e Illas McDonald',
        'HN' => 'Honduras',
        'HR' => 'Croacia',
        'HT' => 'Haití',
        'HU' => 'Hungría',
        'ID' => 'Indonesia',
        'IE' => 'Irlanda',
        'IL' => 'Israel',
        'IM' => 'Illa de Man',
        'IN' => 'A India',
        'IO' => 'Territorio Británico do Océano Índico',
        'IQ' => 'Iraq',
        'IR' => 'Irán',
        'IS' => 'Islandia',
        'IT' => 'Italia',
        'JE' => 'Jersey',
        'JM' => 'Xamaica',
        'JO' => 'Xordania',
        'JP' => 'O Xapón',
        'KE' => 'Kenya',
        'KG' => 'Kirguizistán',
        'KH' => 'Camboxa',
        'KI' => 'Kiribati',
        'KM' => 'Comores',
        'KN' => 'Saint Kitts e Nevis',
        'KP' => 'Corea do Norte',
        'KR' => 'Corea do Sur',
        'KW' => 'Kuwait',
        'KY' => 'Illas Caimán',
        'KZ' => 'Kazakistán',
        'LA' => 'Laos',
        'LB' => 'O Líbano',
        'LC' => 'Santa Lucía',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Liberia',
        'LS' => 'Lesotho',
        'LT' => 'Lituania',
        'LU' => 'Luxemburgo',
        'LV' => 'Letonia',
        'LY' => 'Libia',
        'MA' => 'Marrocos',
        'MC' => 'Mónaco',
        'MD' => 'Moldavia',
        'ME' => 'Montenegro',
        'MF' => 'Saint Martin',
        'MG' => 'Madagascar',
        'MH' => 'Illas Marshall',
        'MK' => 'Macedonia do Norte',
        'ML' => 'Malí',
        'MM' => 'Myanmar (Birmania)',
        'MN' => 'Mongolia',
        'MO' => 'Macau RAE da China',
        'MP' => 'Illas Marianas do Norte',
        'MQ' => 'Martinica',
        'MR' => 'Mauritania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauricio',
        'MV' => 'Maldivas',
        'MW' => 'Malawi',
        'MX' => 'México',
        'MY' => 'Malaisia',
        'MZ' => 'Mozambique',
        'NA' => 'Namibia',
        'NC' => 'Nova Caledonia',
        'NE' => 'Níxer',
        'NF' => 'Illa Norfolk',
        'NG' => 'Nixeria',
        'NI' => 'Nicaragua',
        'NL' => 'Países Baixos',
        'NO' => 'Noruega',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Nova Zelandia',
        'OM' => 'Omán',
        'PA' => 'Panamá',
        'PE' => 'O Perú',
        'PF' => 'A Polinesia Francesa',
        'PG' => 'Papúa-Nova Guinea',
        'PH' => 'Filipinas',
        'PK' => 'Paquistán',
        'PL' => 'Polonia',
        'PM' => 'Saint Pierre et Miquelon',
        'PN' => 'Illas Pitcairn',
        'PR' => 'Porto Rico',
        'PS' => 'Territorios Palestinos',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'O Paraguai',
        'QA' => 'Qatar',
        'RE' => 'Reunión',
        'RO' => 'Romanía',
        'RS' => 'Serbia',
        'RU' => 'Rusia',
        'RW' => 'Ruanda',
        'SA' => 'Arabia Saudita',
        'SB' => 'Illas Salomón',
        'SC' => 'Seychelles',
        'SD' => 'O Sudán',
        'SE' => 'Suecia',
        'SG' => 'Singapur',
        'SH' => 'Santa Helena',
        'SI' => 'Eslovenia',
        'SJ' => 'Svalbard e Jan Mayen',
        'SK' => 'Eslovaquia',
        'SL' => 'Serra Leoa',
        'SM' => 'San Marino',
        'SN' => 'Senegal',
        'SO' => 'Somalia',
        'SR' => 'Suriname',
        'SS' => 'O Sudán do Sur',
        'ST' => 'San Tomé e Príncipe',
        'SV' => 'O Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'Siria',
        'SZ' => 'Eswatini',
        'TC' => 'Illas Turks e Caicos',
        'TD' => 'Chad',
        'TF' => 'Territorios Austrais Franceses',
        'TG' => 'Togo',
        'TH' => 'Tailandia',
        'TJ' => 'Taxiquistán',
        'TK' => 'Tokelau',
        'TL' => 'Timor Leste',
        'TM' => 'Turkmenistán',
        'TN' => 'Tunisia',
        'TO' => 'Tonga',
        'TR' => 'Turquía',
        'TT' => 'Trinidad e Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwán',
        'TZ' => 'Tanzania',
        'UA' => 'Ucraína',
        'UG' => 'Uganda',
        'UM' => 'Illas Menores Distantes dos Estados Unidos',
        'US' => 'Os Estados Unidos',
        'UY' => 'O Uruguai',
        'UZ' => 'Uzbekistán',
        'VA' => 'Cidade do Vaticano',
        'VC' => 'San Vicente e As Granadinas',
        'VE' => 'Venezuela',
        'VG' => 'Illas Virxes Británicas',
        'VI' => 'Illas Virxes Estadounidenses',
        'VN' => 'Vietnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis e Futuna',
        'WS' => 'Samoa',
        'YE' => 'O Iemen',
        'YT' => 'Mayotte',
        'ZA' => 'Suráfrica',
        'ZM' => 'Zambia',
        'ZW' => 'Zimbabwe',
    ],
];

==> symfony_7.3.4+dfsg.orig.tar.xz: symfony-7.3.4/src/Symfony/Component/Intl/Resources/data/regions/gl.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosovo',
    ],
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Emiratos Árabes Unidos',
        'AF' => 'Afganistán',
        'AG' => 'Antigua e Barbuda',
        'AI' => 'Anguila',
        'AL' => 'Albania',
        'AM' => 'Armenia',
        'AO' => 'Angola',
        'AQ' => 'Antártida',
        'AR' => 'Arxentina',
        'AS' => 'Samoa Americana',
        'AT' => 'Austria',
        'AU' => 'Australia',
        'AW' => 'Aruba',
        'AX' => 'Illas Åland',
        'AZ' => 'Acerbaixán',
        'BA' => 'Bosnia e Hercegovina',
        'BB' => 'Barbados',
        'BD' => 'Bangladesh',
        'BE' => 'Bélxica',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgaria',
        'BH' => 'Bahrain',
        'BI' => 'Burundi',
        'BJ' => 'Benín',
        'BL' => 'Saint Barthélemy',
        'BM' => 'Illas Bermudas',
        'BN' => 'Brunei',
        'BO' => 'Bolivia',
        'BQ' => 'Caribe Neerlandés',
        'BR' => 'Brasil',
        'BS' => 'Bahamas',
        'BT' => 'Bután',
        'BV' => 'Illa Bouvet',
        'BW' => 'Botswana',
        'BY' => 'Belarús',
        'BZ' => 'Belize',
        'CA' => 'Canadá',
        'CC' => 'Illas Cocos (Keeling)',
        'CD' => 'República Democrática do Congo',
        'CF' => 'República Centroafricana',
        'CG' => 'República do Congo',
        'CH' => 'Suíza',
        'CI' => 'Côte d’Ivoire',
        'CK' => 'Illas Cook',
        'CL' => 'Chile',
        'CM' => 'Camerún',
        'CN' => 'China',
        'CO' => 'Colombia',
        'CR' => 'Costa Rica',
        'CU' => 'Cuba',
        'CV' => 'Cabo Verde',
        'CW' => 'Curaçao',
        'CX' => 'Illa Christmas',
        'CY' => 'Chipre',
        'CZ' => 'Chequia',
        'DE' => 'Alemaña',
        'DJ' => 'Djibuti',
        'DK' => 'Dinamarca',
        'DM' => 'Dominica',
        'DO' => 'República Dominicana',
        'DZ' => 'Alxeria',
        'EC' => 'Ecuador',
        'EE' => 'Estonia',
        'EG' => 'Exipto',
        'EH' => 'Sáhara Occidental',
        'ER' => 'Eritrea',
        'ES' => 'España',
        'ET' => 'Etiopía',
        'FI' => 'Finlandia',
        'FJ' => 'Fixi',
        'FK' => 'Illas Malvinas',
        'FM' => 'Micronesia',
        'FO' => 'Illas Feroe',
        'FR' => 'Francia',
        'GA' => 'Gabón',
        'GB' => 'Reino Unido',
        'GD' => 'Granada',
        'GE' => 'Xeorxia',
        'GF' => 'Güiana Francesa',
        'GG' => 'Guernsey',
        'GH' => 'Ghana',
        'GI' => 'Xibraltar',
        'GL' => 'Groenlandia',
        'GM' => 'Gambia',
        'GN' => 'Guinea',
        'GP' => 'Guadalupe',
        'GQ' => 'Guinea Ecuatorial',
        'GR' => 'Grecia',
        'GS' => 'Illas Xeorxia do Sur e Sandwich do Sur',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'Guinea Bissau',
        'GY' => 'Güiana',
        'HK' => 'Hong Kong RAE da China',
        'HM' => 'Illa Heard e Illas McDonald',
        'HN' => 'Honduras',
        'HR' => 'Croacia',
        'HT' => 'Haití',
        'HU' => 'Hungría',
        'ID' => 'Indonesia',
        'IE' => 'Irlanda',
        'IL' => 'Israel',
        'IM' => 'Illa de Man',
        'IN' => 'India',
        'IO' => 'Territorio Británico do Océano Índico',
        'IQ' => 'Iraq',
        'IR' => 'Irán',
        'IS' => 'Islandia',
        'IT' => 'Italia',
        'JE' => 'Jersey',
        'JM' => 'Xamaica',
        'JO' => 'Xordania',
        'JP' => 'Xapón',
        'KE' => 'Kenya',
        'KG' => 'Kirguizistán',
        'KH' => 'Camboxa',
        'KI' => 'Kiribati',
        'KM' => 'Comores',
        'KN' => 'Saint Kitts e Nevis',
        'KP' => 'Corea do Norte',
        'KR' => 'Corea do Sur',
        'KW' => 'Kuwait',
        'KY' => 'Illas Caimán',
        'KZ' => 'Kazakistán',
        'LA' => 'Laos',
        'LB' => 'Líbano',
        'LC' => 'Santa Lucía',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Liberia',
        'LS' => 'Lesotho',
        'LT' => 'Lituania',
        'LU' => 'Luxemburgo',
        'LV' => 'Letonia',
        'LY' => 'Libia',
        'MA' => 'Marrocos',
        'MC' => 'Mónaco',
        'MD' => 'República Moldova',
        'ME' => 'Montenegro',
        'MF' => 'Saint Martin',
        'MG' => 'Madagascar',
        'MH' => 'Illas Marshall',
        'MK' => 'Macedonia do Norte',
        'ML' => 'Malí',
        'MM' => 'Myanmar (Birmania)',
        'MN' => 'Mongolia',
        'MO' => 'Macau RAE da China',
        'MP' => 'Illas Marianas do Norte',
        'MQ' => 'Martinica',
        'MR' => 'Mauritania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauricio',
        'MV' => 'Maldivas',
        'MW' => 'Malawi',
        'MX' => 'México',
        'MY' => 'Malaisia',
        'MZ' => 'Mozambique',
        'NA' => 'Namibia',
        'NC' => 'Nova Caledonia',
        'NE' => 'Níxer',
        'NF' => 'Illa Norfolk',
        'NG' => 'Nixeria',
        'NI' => 'Nicaragua',
        'NL' => 'Países Baixos',
        'NO' => 'Noruega',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Nova Zelandia',
        'OM' => 'Omán',
        'PA' => 'Panamá',
        'PE' => 'Perú',
        'PF' => 'Polinesia Francesa',
        'PG' => 'Papúa-Nova Guinea',
        'PH' => 'Filipinas',
        'PK' => 'Paquistán',
        'PL' => 'Polonia',
        'PM' => 'Saint Pierre et Miquelon',
        'PN' => 'Illas Pitcairn',
        'PR' => 'Porto Rico',
        'PS' => 'Territorios Palestinos',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Paraguai',
        'QA' => 'Qatar',
        'RE' => 'Reunión',
        'RO' => 'Romanía',
        'RS' => 'Serbia',
        'RU' => 'Rusia',
        'RW' => 'Ruanda',
        'SA' => 'Arabia Saudita',
        'SB' => 'Illas Salomón',
        'SC' => 'Seychelles',
        'SD' => 'Sudán',
        'SE' => 'Suecia',
        'SG' => 'Singapur',
        'SH' => 'Santa Helena',
        'SI' => 'Eslovenia',
        'SJ' => 'Svalbard e Jan Mayen',
        'SK' => 'Eslovaquia',
        'SL' => 'Serra Leoa',
        'SM' => 'San Marino',
        'SN' => 'Senegal',
        'SO' => 'Somalia',
        'SR' => 'Suriname',
        'SS' => 'Sudán do Sur',
        'ST' => 'San Tomé e Príncipe',
        'SV' => 'O Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'Siria',
        'SZ' => 'Eswatini',
        'TC' => 'Illas Turks e Caicos',
        'TD' => 'Chad',
        'TF' => 'Territorios Austrais Franceses',
        'TG' => 'Togo',
        'TH' => 'Tailandia',
        'TJ' => 'Taxiquistán',
        'TK' => 'Tokelau',
        'TL' => 'Timor Leste',
        'TM' => 'Turkmenistán',
        'TN' => 'Tunisia',
        'TO' => 'Tonga',
        'TR' => 'Turquía',
        'TT' => 'Trinidad e Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwán',
        'TZ' => 'Tanzania',
        'UA' => 'Ucraína',
        'UG' => 'Uganda',
        'UM' => 'Illas Menores Distantes dos Estados Unidos',
        'US' => 'Estados Unidos',
        'UY' => 'Uruguai',
        'UZ' => 'Uzbekistán',
        'VA' => 'Cidade do Vaticano',
        'VC' => 'San Vicente e as Granadinas',
        'VE' => 'Venezuela',
        'VG' => 'Illas Virxes Británicas',
        'VI' => 'Illas Virxes Estadounidenses',
        'VN' => 'Vietnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis e Futuna',
        'WS' => 'Samoa',
        'YE' => 'Iemen',
        'YT' => 'Mayotte',
        'ZA' => 'Suráfrica',
        'ZM' => 'Zambia',
        'ZW' => 'Zimbabwe',
    ],
];
